## My Calculator

This package computes the various computations of Maths like :
* Greatest Common Divisor
* Lowest Common Multiple
* Reducing Fraction

## Installations
__Through pypi package__
``` Shell
$ pip install my-calculator
```

__From Source__
``` Shell
$ git clone git@github.com:ghimireadarsh/My-Calculator.git
$ cd My-Calculator
$ pip install . 
```

## Usage
After the package is installed, several operation can be performed like:

__Greatest Common Divisor__
``` Python
from my_calculator import Calculator
Calculator.gcd(10,12)
# Output : 2
```

__Lowest Common Multiple__
``` Python
from my_calculator import Calculator
Calculator.lcm(10,12)
# Output : 60
```

__Fraction reducer__
``` Python
from my_calculator import Calculator
Calculator.reduce_fraction(10,12)
# Output : (5,6)
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://github.com/ghimireadarsh/My-Calculator/blob/master/LICENSE.txt)

### TO DO:
1. Computations of LCM and GCD for list of numbers
2. Other functions addition